@@ -99,16 +99,17 @@ totem_pl_parser_add_videosite (TotemPlParser *parser,
 	uri = g_file_get_uri (file);
 	rc = quvi_parse(handle, uri, &v);
 	if (rc != QUVI_OK) {
-		if (totem_pl_parser_is_debugging_enabled (parser)) {
+		if (totem_pl_parser_is_debugging_enabled (parser))
 			g_print ("quvi_parse for '%s' returned %d\n", uri, rc);
-		}
 		g_free (uri);
 		quvi_close (&handle);
+		if (rc == QUVI_NOSUPPORT)
+			return TOTEM_PL_PARSER_RESULT_UNHANDLED;
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 	}
 
 	getprop (QUVIPROP_MEDIAURL, video_uri);
-	if (quvi_getprop (v, QUVIPROP_MEDIACONTENTLENGTH, &length) == QUVI_OK)
+	if (quvi_getprop (v, QUVIPROP_MEDIACONTENTLENGTH, &length) == QUVI_OK && length)
 		length_str = g_strdup_printf ("%f", length);
 	else
 		length_str = NULL;
