@@ -986,7 +986,7 @@ is_probably_dir (const char *filename)
 	short_name = relative_uri_remove_query (filename, NULL);
 	if (short_name == NULL)
 		short_name = g_strdup (filename);
-	content_type = g_content_type_guess (short_name, NULL, -1, NULL);
+	content_type = g_content_type_guess (short_name, NULL, 0, NULL);
 	if (g_content_type_is_unknown (content_type) != FALSE) {
 		guint i;
 		for (i = 0; i < G_N_ELEMENTS (suffixes); i++) {
@@ -1826,6 +1826,18 @@ totem_pl_parser_parse_internal (TotemPlParser *parser,
 		g_free (uri);
 	}
 
+	/* We're much more likely to have an MP2T file instead */
+	if (g_strcmp0 (mimetype, "application/x-linguist") == 0 ||
+	    g_strcmp0 (mimetype, "text/vnd.trolltech.linguist") == 0) {
+		g_free (mimetype);
+		mimetype = g_strdup ("video/mp2t");
+	}
+
+	/* Not a directory on http though */
+	if (g_strcmp0 (mimetype, "inode/directory") == 0 &&
+	    g_file_has_uri_scheme (file, "http"))
+		g_clear_pointer (&mimetype, g_free);
+
 	DEBUG(file, g_print ("_get_mime_type_for_name for '%s' returned '%s'\n", uri, mimetype));
 	if (mimetype == NULL || strcmp (UNKNOWN_TYPE, mimetype) == 0
 	    || (g_file_is_native (file) && g_content_type_is_a (mimetype, "text/plain") != FALSE)) {
@@ -2436,8 +2448,11 @@ totem_pl_parser_can_parse_from_data (const char *data,
  * @filename: the file to check for parsability
  * @debug: %TRUE if debug statements should be printed
  *
- * Checks if the file can be parsed, using the same checks and precedences
- * as totem_pl_parser_ignore().
+ * Checks if the file can be parsed. Files can be parsed if:
+ * <itemizedlist>
+ *  <listitem><para>they have a special mimetype, or</para></listitem>
+ *  <listitem><para>they have a mimetype which could be a video or a playlist.</para></listitem>
+ * </itemizedlist>
  *
  * Return value: %TRUE if @filename can be parsed
  **/
